@@ -1,5 +1,9 @@
+import warnings
+
 from flask import Blueprint
 
+warnings.filterwarnings("ignore")
+
 dtale = Blueprint("dtale", __name__, url_prefix="/dtale")
 
 # flake8: NOQA
