@@ -1,10 +1,9 @@
 import dash_bootstrap_components as dbc
-import dash_core_components as dcc
-import dash_html_components as html
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 
 from dtale.charts.utils import ANIMATION_CHARTS, ANIMATE_BY_CHARTS, ZAXIS_CHARTS
+from dtale.dash_application import dcc, html
 from dtale.dash_application.charts import build_chart, valid_chart
 from dtale.dash_application.layout.utils import build_hoverable
 from dtale.utils import dict_merge, is_app_root_defined, flatten_lists, make_list
@@ -92,6 +91,10 @@ def build_saved_header(config):
         group_by = config["funnel_group"]
         for prop in ["funnel_value", "funnel_label"]:
             final_data.append((prop.split("_")[-1], config.get(prop)))
+    elif chart_type == "clustergram":
+        group_by = config["clustergram_group"]
+        for prop in ["clustergram_value", "clustergram_label"]:
+            final_data.append((prop.split("_")[-1], config.get(prop)))
     else:
         group_by = config.get("group")
         final_data.append(("X-Axis", config["x"]))
@@ -228,7 +231,7 @@ def init_callbacks(dash_app):
                 Output("prev-saved-chart-config-{}".format(i), "data"),
                 Output("saved-chart-header-{}".format(i), "children"),
             ],
-            Input("saved-chart-config-{}".format(i), "modified_timestamp"),
+            [Input("saved-chart-config-{}".format(i), "modified_timestamp")],
             [
                 State("saved-chart-config-{}".format(i), "data"),
                 State("prev-saved-chart-config-{}".format(i), "data"),
