@@ -20,6 +20,10 @@ APP_SETTINGS = {
     "max_row_height": None,
     "main_title": None,
     "main_title_font": None,
+    "query_engine": "python",
+    "open_custom_filter_on_startup": False,
+    "open_predefined_filters_on_startup": False,
+    "hide_drop_rows": False,
 }
 
 AUTH_SETTINGS = {
