@@ -16,7 +16,7 @@ import numpy as np
 import pandas as pd
 from pkg_resources import parse_version
 from past.utils import old_div
-from six import StringIO
+from six import BytesIO, StringIO
 
 logger = getLogger(__name__)
 
@@ -556,6 +556,23 @@ def grid_formatter(col_types, nan_display="", overrides=None, as_string=False):
     return f
 
 
+def build_formatters(df, nan_display=None):
+    """
+    Helper around :meth:`dtale.utils.grid_formatters` that will build a formatter for the data being fed into a chart as
+    well as a formatter for the min/max values for each column used in the chart data.
+
+    :param df: dataframe which contains column names and data types for formatters
+    :type df: :class:`pandas:pandas.DataFrame`
+    :return: json formatters for chart data and min/max values for each column used in the chart
+    :rtype: (:class:`dtale.utils.JSONFormatter`, :class:`dtale.utils.JSONFormatter`)
+    """
+    cols = grid_columns(df)
+    data_f = grid_formatter(cols, nan_display=nan_display)
+    overrides = {"F": lambda f, i, c: f.add_float(i, c, precision=2)}
+    range_f = grid_formatter(cols, overrides=overrides, nan_display=nan_display)
+    return data_f, range_f
+
+
 def format_grid(df, overrides=None):
     """
     Translate :class:`pandas:pandas.DataFrame` to well-formed JSON.  Structure is as follows:
@@ -728,6 +745,20 @@ def export_to_csv_buffer(data, tsv=False):
     return csv_buffer
 
 
+def export_to_parquet_buffer(data):
+    try:
+        import pyarrow  # noqa: F401
+    except ImportError:
+        raise ImportError(
+            "In order to use the parquet exporter you must install pyarrow!"
+        )
+    kwargs = dict(compression="gzip", index=False)
+    parquet_buffer = BytesIO()
+    data.to_parquet(parquet_buffer, **kwargs)
+    parquet_buffer.seek(0)
+    return parquet_buffer
+
+
 def is_app_root_defined(app_root):
     return app_root is not None and app_root != "/"
 
